@@ -99,6 +99,7 @@ class cgyrodata_plot(data.cgyrodata):
 
       fig.tight_layout(pad=0.3)
 
+
    def plot_ky_freq(self,w=0.5,wmax=0.0,norm='elec',fig=None):
 
       if fig is None:
@@ -114,8 +115,9 @@ class cgyrodata_plot(data.cgyrodata):
       ax.set_xlabel(self.kstr)
       ax.set_ylabel(self.fstr[0])
 
-      ax.plot(ky,self.fnorm[0,:,-1],color='blue')
-      ax.plot(ky,self.fnorm[0,:,-1],"o",color='k')
+      y1 = self.fnorm[0,:,-1] 
+      ax.plot(ky,y1,color='blue')
+      ax.plot(ky,y1,"o",color='k')
       if len(ky) > 1:
          ax.set_xlim([0,ky[-1]])
       #======================================
@@ -128,14 +130,17 @@ class cgyrodata_plot(data.cgyrodata):
       ax.set_xlabel(self.kstr)
       ax.set_ylabel(self.fstr[1])
 
-      ax.plot(ky,self.fnorm[1,:,-1],color='red')
-      ax.plot(ky,self.fnorm[1,:,-1],"o",color='k')
+      y2 = self.fnorm[1,:,-1] 
+      ax.plot(ky,y2,color='red')
+      ax.plot(ky,y2,"o",color='k')
       if len(ky) > 1:
          ax.set_xlim([0,ky[-1]])
       #======================================
 
       fig.tight_layout(pad=0.3)
 
+      return 'ky            omega            gamma',ky,y1,y2
+
    def plot_ky_phi(self,field=0,theta=0.0,ymin='auto',ymax='auto',nstr='null',norm='elec',fig=None):
 
       # Plot fields versus time for particular values of ky
@@ -1277,13 +1282,13 @@ class cgyrodata_plot(data.cgyrodata):
 
          if row == 0:
             ie = 0
-            ix = 0
+            ix = 2
          if row == 1:
-            ie = self.n_energy/2
-            ix = self.n_xi/2
+            ie = self.n_energy//2
+            ix = 3
          if row == 2:
             ie = self.n_energy-1
-            ix = self.n_xi-1
+            ix = 5
 
          #========================================================
          ax = fig.add_subplot(3,3,p)
@@ -1294,10 +1299,10 @@ class cgyrodata_plot(data.cgyrodata):
          ax.set_xlabel(r'$\theta/\pi$')
 
          if self.n_xi%2 == 0:
-            hp = np.array(func[:,:,spec,self.n_xi/2,ie,itime]+
-                          func[:,:,spec,self.n_xi/2-1,ie,itime])*0.5
+            hp = np.array(func[:,:,spec,self.n_xi//2,ie,itime]+
+                          func[:,:,spec,self.n_xi//2-1,ie,itime])*0.5
          else:
-            hp = np.array(func[:,:,spec,self.n_xi/2,ie,itime])
+            hp = np.array(func[:,:,spec,self.n_xi//2,ie,itime])
             
          ax.plot(x,hp[0,:],'-o',color='black',markersize=2)
          ax.plot(x,hp[1,:],'-o',color='blue',markersize=2)
@@ -1315,7 +1320,7 @@ class cgyrodata_plot(data.cgyrodata):
          ax.set_title(r'$'+u+': \\theta/\pi='+str(theta)+' \quad \mathrm{ie}='+str(ie)+'$')
          ax.set_xlabel(r'$\xi = v_\parallel/v$')
 
-         n0 = (self.n_radial/2)*self.n_theta+i0
+         n0 = (self.n_radial//2)*self.n_theta+i0
          
          hp = np.array(func[0,:,spec,:,ie,itime])
          ax.plot(self.xi,hp[n0,:],'-o',color='black',markersize=2)
@@ -1334,27 +1339,15 @@ class cgyrodata_plot(data.cgyrodata):
          ax.set_title(r'$'+u+': \\theta/\pi='+str(theta)+' \quad \mathrm{ix}='+str(ix)+'$')
          ax.set_xlabel(r'$x=\sqrt{\varepsilon}$')
 
-         n0 = (self.n_radial/2)*self.n_theta+i0
+         n0 = (self.n_radial//2)*self.n_theta+i0
 
          hpa = np.array(func[0,n0,spec,:,:,itime])
          hpb = np.array(func[1,n0,spec,:,:,itime])
          p0 = np.zeros(self.n_energy)
          p1 = np.zeros(self.n_energy)
-         if row == 0:
-            for ix in range(self.n_xi):
-               p0 = p0+hpa[ix,:]*0.5
-               p1 = p1+hpb[ix,:]*0.5
-         elif row == 1:
-            for ix in range(self.n_xi):
-               p0 = p0+hpa[ix,:]*self.xi[ix]*1.5
-               p1 = p1+hpb[ix,:]*self.xi[ix]*1.5
-         elif row == 2:
-            for ix in range(self.n_xi):
-               p0 = p0+hpa[ix,:]*(3*self.xi[ix]**2-1)/2*2.5
-               p1 = p1+hpb[ix,:]*(3*self.xi[ix]**2-1)/2*2.5
-            
-         ax.plot(np.sqrt(self.energy),p0,'-o',color='black',markersize=2)
-         ax.plot(np.sqrt(self.energy),p1,'-o',color='blue',markersize=2)
+                        
+         ax.plot(np.sqrt(self.energy),hpa[ix,:],'-o',color='black',markersize=2)
+         ax.plot(np.sqrt(self.energy),hpb[ix,:],'-o',color='blue',markersize=2)
          #========================================================
 
       fig.tight_layout(pad=0.3)
