@@ -8,9 +8,11 @@ from ..gacodefuncs import *
 from .data import cgyrodata
 from mayavi import mlab 
 try:
-   import pygacode
+   from pygacode import vis
+   from pygacode import geo
+   print("INFO: (vis_torcut) Successfully imported vis")
 except:
-   print("ERROR: (vis_torcut) Please type 'make so' in gacode/f2py")
+   print("ERROR: (vis_torcut) Please type 'pip install pygacode'")
    sys.exit()
    
 ext      = sys.argv[1]
@@ -154,7 +156,7 @@ def frame():
    
    # 1a
    f = np.zeros([nx,ny],order='F')
-   pygacode.realfluct(c[:,nth//2,:],f)
+   vis.realfluct(c[:,nth//2,:],f)
 
    if fmin == 'auto':
       f0=np.min(f)
@@ -167,18 +169,18 @@ def frame():
 
    # 1b
    f = np.zeros([nx,ny],order='F')
-   pygacode.realfluct(c[:,0,:],f)
+   vis.realfluct(c[:,0,:],f)
    mlab.mesh(-xp1,yp1,zp1,scalars=f,colormap=colormap,vmin=f0,vmax=f1)
 
    # 2a,b
    f = np.zeros([nx,nz],order='F')
-   pygacode.wheel1(c,f)
+   vis.wheel1(c,f)
    mlab.mesh(xp2,yp2,zp2,scalars=f,colormap=colormap,vmin=f0,vmax=f1)
    mlab.mesh(xp2,yp2,0*zp2,scalars=f,colormap=colormap,vmin=f0,vmax=f1)
 
    # 3a,b
    f = np.zeros([ny,nz],order='F')
-   pygacode.wheel2(c,f)
+   vis.wheel2(c,f)
    mlab.mesh(xp3,yp3,zp3,scalars=f,colormap=colormap,vmin=f0,vmax=f1)
    mlab.mesh(xp4,yp4,zp4,scalars=f,colormap=colormap,vmin=f0,vmax=f1)
 
